@@ -176,6 +176,7 @@ EVENT_SINK_INVOKE(MailItemEvents)
                          SRCNAME, __func__);
               m_mail->setIsDraftEncrypt (true);
               m_mail->prepareCrypto_o ();
+              m_mail->encryptSignStart_o ();
             }
           TRETURN S_OK;
         }
@@ -689,7 +690,8 @@ TODO: Handle split copy in another way
                              SRCNAME, __func__);
                   m_mail->setIsDraftEncrypt (true);
                   m_mail->prepareCrypto_o ();
-                  /* Passing write to trigger encrypt in after write */
+                  m_mail->encryptSignStart_o ();
+                  /* Draft encryption happens synchronously so we pass it. */
                   TBREAK;
                 }
               if (m_mail->cryptState() == Mail::CryptFinished)
@@ -845,7 +847,8 @@ TODO: Handle split copy in another way
                     */
                   log_oom ("%s:%s: Passing close because of draft status: %p",
                            SRCNAME, __func__, m_mail);
-                  m_mail->setDecryptAgain (true);
+                  /* Clear selections to avoid conflicts with inline editors */
+                  oom_clear_selections ();
                   TBREAK;
                 }
               /* Close. This happens when an Opened mail is closed.
